Learn R Programming

nettskjemar (version 1.0.1)

ns_get_forms: Get all forms you have access to

Description

All users have access to specific forms, and this function uses the token provided to check what the current user has access to.

Usage

ns_get_forms(asis = FALSE)

Value

data.frame, if asis = TRUE returns a list

Arguments

asis

logical. Whether to return the raw content from nettskjema. Default is FALSE.