Learn R Programming

nettskjemar (version 1.0.1)

ns_list_submission_attachments: List Nettskjema attachments for a submission

Description

Each unique submission ID in Nettskjema may have some attachments. These can be listed using this function, which will provide the information on where in the Nettskjema API the files are located, their original file names, and a suggested standardized file names for tidier data output.

Usage

ns_list_submission_attachments(submission_id)

Value

a data.frame with information on attachments available.

Arguments

submission_id

integer. Unique identifier of a specific Nettskjema submission.

Examples

Run this code
if (FALSE) {
submission_id <- 22222
ns_list_submission_attachments(submission_id)

}

Run the code above in your browser using DataLab