Learn R Programming

nettskjemar (version 1.0.1)

ns_get_data: Get data from a form

Description

This function connects to a specific form and fetches all answers. The responses are placed in a data.frame for easy use.

Usage

ns_get_data(form_id, type = NULL)

ns_get_submissions(form_id, type = NULL)

Value

data.frame

Arguments

form_id

integer. Number of the form to retrieve

type

Character or NULL. One of either "original" or "long".

Functions

  • ns_get_submissions(): Alternative function name, does the same.

Details

"original"

- Returns data in the same tabular format as delivered by Nettskjema.

"long"

- Returns the data in tall format, where there are multiple rows per participant (one per question) and each choice is timestamped.

Examples

Run this code
if (FALSE) {

# Retrieve all data
data_110000 <- ns_get_data(110000)

}

Run the code above in your browser using DataLab