powered by
This function connects to a specific form and fetches all answers. The responses are placed in a data.frame for easy use.
ns_get_data(form_id, type = NULL)ns_get_submissions(form_id, type = NULL)
ns_get_submissions(form_id, type = NULL)
data.frame
integer. Number of the form to retrieve
Character or NULL. One of either "original" or "long".
ns_get_submissions(): Alternative function name, does the same.
ns_get_submissions()
- Returns data in the same tabular format as delivered by Nettskjema.
- Returns the data in tall format, where there are multiple rows per participant (one per question) and each choice is timestamped.
if (FALSE) { # Retrieve all data data_110000 <- ns_get_data(110000) }
Run the code above in your browser using DataLab