powered by
Sets the API url and access token. This is used for almost all the functionality in this package. If you want to use endpoints not yet covered by functions in the package, this is the basis function you can build from.
ns_req(...)
httr2 request
httr2
arguments passed to ns_auth_token
ns_auth_token
if (FALSE) { ns_req() |> httr2::req_url_path_append("form", "me") |> httr2::req_perform() |> httr2::resp_body_json() }
Run the code above in your browser using DataLab